'use strict';

const Unocss = require('@unocss/webpack');
const unocss = require('unocss');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e["default"] : e; }

const Unocss__default = /*#__PURE__*/_interopDefaultLegacy(Unocss);

const remRE = /^-?[\.\d]+rem$/;
const presetRemToRpx = (options = {}) => {
  const {
    baseFontSize = 16,
    isH5 = false
  } = options;
  return {
    name: "@unocss/preset-rem-to-rpx",
    postprocess: (util) => {
      if (isH5) {
        util.entries.forEach((i) => {
          const value = i[1];
          if (value && typeof value === "string" && remRE.test(value))
            i[1] = `${+value.slice(0, -3) * baseFontSize / 40}rem`;
        });
        return;
      }
      util.entries.forEach((i) => {
        const value = i[1];
        if (value && typeof value === "string" && remRE.test(value))
          i[1] = `${+value.slice(0, -3) * baseFontSize}rpx`;
      });
    }
  };
};

const index = (ctx, unocssPluginOptions) => {
  const { options, defaults, preset } = unocssPluginOptions || {};
  const { uno = {}, remToRpx = {}, attributify = {}, typography = {} } = preset || {};
  ctx.modifyWebpackChain(({ chain }) => {
    const isH5 = ctx.platforms.has("h5");
    const unocssPresets = [
      unocss.presetUno(uno),
      unocss.presetAttributify(attributify),
      unocss.presetTypography(typography)
    ];
    unocssPresets.push(presetRemToRpx({ ...remToRpx, isH5 }));
    chain.plugin("unocss").use(Unocss__default({
      ...options || {},
      presets: [
        ...unocssPresets,
        ...options?.presets || []
      ],
      theme: {
        ...options?.theme || {},
        preflightBase: isH5
      }
    }, defaults));
    chain.merge({
      module: {
        rule: {
          mjsScript: {
            test: /\.mjs$/,
            include: [/@unocss/, /unocss/],
            use: {
              babelLoader: {
                loader: require.resolve("babel-loader")
              }
            }
          }
        }
      }
    });
  });
};

module.exports = index;
